@@ -8,7 +8,7 @@
 #' Works by estimating a set of quantiles of the distribution implied
 #' by logf and treating those quantiles as data in a standard Box-Cox
 #' analysis.  In the following we use theta to denote the argument of
-#' logf on the orginal scale and phi on the Box-Cox transformed scale.
+#' logf on the original scale and phi on the Box-Cox transformed scale.
 #'
 #' @param logf A function returning the log of the target density f.
 #' @param ... further arguments to be passed to \code{logf} and related
@@ -32,6 +32,7 @@
 #' @param log_j A function returning the log of the Jacobian of the
 #'   transformation from theta to phi, i.e. based on derivatives of phi with
 #'   respect to theta. Takes theta as its argument.
+#'   If this is not supplied then a constant Jacobian is used.
 #' @details The general idea is to estimate quantiles of f corresponding to a
 #'   set of equally-spaced probabilities in \code{probs} and to use these
 #'   estimated quantiles as data in a standard estimation of the Box-Cox
@@ -110,10 +111,15 @@
 #' plot(x)
 #' plot(x, ru_scale = TRUE)
 #' }
-#' @seealso \code{\link{ru}} to perform ratio-of-uniforms sampling.
-#' @seealso \code{\link{find_lambda}} to produce (somewhat) automatically
-#'   a list for the argument \code{lambda} of \code{ru} for any value of
-#'   \code{d}.
+#' @seealso \code{\link{ru}} and \code{\link{ru_rcpp}} to perform
+#'   ratio-of-uniforms sampling.
+#' @seealso \code{\link{find_lambda}} and \code{\link{find_lambda_rcpp}}
+#'   to produce (somewhat) automatically
+#'   a list for the argument \code{lambda} of \code{ru}/\code{ru_rcpp}
+#'   for any value of \code{d}.
+#' @seealso \code{\link{find_lambda_one_d_rcpp}} for a version of
+#'   \code{\link{find_lambda_one_d}} that uses the Rcpp package to improve
+#'   efficiency.
 #'
 #' @export
 find_lambda_one_d <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
@@ -138,7 +144,6 @@ find_lambda_one_d <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
     if (is.null(log_j)) {
       log_j <- function(x) 0
       trans_list$log_j <- function(x) 0
-      warning("No Jacobian for phi_to_theta(): constant Jacobian has been set")
     }
   } else {
     phi_to_theta <- identity
@@ -209,7 +214,7 @@ find_lambda_one_d <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
 #' the (positive) random variable with log-density logf has a density
 #' closer to that of a Gaussian random variable.
 #' In the following we use theta to denote the argument of
-#' logf on the orginal scale and phi on the Box-Cox transformed scale.
+#' logf on the original scale and phi on the Box-Cox transformed scale.
 #'
 #' @param logf A function returning the log of the target density f.
 #' @param ... further arguments to be passed to \code{logf} and related
@@ -346,6 +351,7 @@ find_lambda_one_d <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
 #' abline(a = 0, b = -1 / ss$xm)
 #' summary(x4)
 #'
+#' def_par <- graphics::par(no.readonly = TRUE)
 #' par(mfrow = c(2,2), mar = c(4, 4, 1.5, 1))
 #' plot(x1, xlab = "sigma", ylab = "xi", ru_scale = TRUE,
 #'   main = "mode relocation")
@@ -355,11 +361,17 @@ find_lambda_one_d <- function(logf, ..., ep_bc = 1e-4, min_phi = ep_bc,
 #'   main = "Box-Cox and mode relocation")
 #' plot(x4, xlab = "sigma", ylab = "xi", ru_scale = TRUE,
 #'   main = "Box-Cox, mode relocation and rotation")
+#' par(def_par)
 #' }
-#' @seealso \code{\link{ru}} to perform ratio-of-uniforms sampling.
-#' @seealso \code{\link{find_lambda_one_d}} to produce (somewhat) automatically
-#'   a list for the argument \code{lambda} of \code{ru} for the
+#' @seealso \code{\link{ru}} and \code{\link{ru_rcpp}} to perform
+#'   ratio-of-uniforms sampling.
+#' @seealso \code{\link{find_lambda_one_d}} and
+#'   \code{\link{find_lambda_one_d_rcpp}} to produce (somewhat) automatically
+#'   a list for the argument \code{lambda} of \code{ru}/\code{ru_rcpp} for the
 #'   \code{d} = 1 case.
+#' @seealso \code{\link{find_lambda_rcpp}} for a version of
+#'   \code{\link{find_lambda}} that uses the Rcpp package to improve
+#'   efficiency.
 #' @export
 find_lambda <- function(logf, ..., d = 1, n_grid = NULL, ep_bc = 1e-4,
                         min_phi = rep(ep_bc, d), max_phi = rep(10, d),
@@ -393,7 +405,6 @@ find_lambda <- function(logf, ..., d = 1, n_grid = NULL, ep_bc = 1e-4,
     if (is.null(log_j)) {
       log_j <- function(x) 0
       trans_list$log_j <- function(x) 0
-      warning("No Jacobian for phi_to_theta(): constant Jacobian has been set")
     }
   } else {
     phi_to_theta <- identity
@@ -415,7 +426,7 @@ find_lambda <- function(logf, ..., d = 1, n_grid = NULL, ep_bc = 1e-4,
   low_phi <- min_phi
   up_phi <- max_phi
   # Create matrix with each column giving the values of each variable
-  phi <- mapply(seq, from = low_phi, to = up_phi, len=n_grid)
+  phi <- mapply(seq, from = low_phi, to = up_phi, len = n_grid)
   # Make this matrix into a list with an entry for each column
   phi <- lapply(seq_len(ncol(phi)), function(i) phi[, i])
   # Expand into a matrix containing the grid of combinations (one
@@ -460,8 +471,8 @@ box_cox <- function (x, lambda = 1, gm = 1, lambda_tol = 1e-6) {
   # Args:
   #   x          : A numeric vector. (Positive) values to be Box-Cox
   #                transformed.
-  #   lambda     : A numeric vector.  Transformation parameter.
-  #   gm         : A numeric vector.  Optional scaling parameter.
+  #   lambda     : A numeric scalar.  Transformation parameter.
+  #   gm         : A numeric scalar.  Optional scaling parameter.
   #   lambda_tol : A numeric scalar.  For abs(lambda) < lambda.tol use
   #                a Taylor series expansion.
   #
